@@ -1,12 +1,44 @@
 import os
 
-from kaggle.api import KaggleApi
+try:
+    from kaggle.api import KaggleApi
+except OSError as err:
+    raise OSError(f"""{err}
+Do you have a kaggle API token? Did you put it in the right place? 
+See https://github.com/Kaggle/kaggle-api#api-credentials for more information.
+It's quick and easy (oh, and free!)!!
+""")
+except ModuleNotFoundError as err:
+    raise ModuleNotFoundError(f"""{err}
+You might try to do a `pip install kaggle` in the terminal?
+""")
+
 from py2store import KvReader, FilesOfZip
 from py2store.util import lazyprop
 
 DFLT_MAX_ITEMS = 200
 DFLT_MAX_PAGES = 10
 
+ROOTDIR_ENVVAR = 'HAGGLE_ROOTDIR'
+DFLT_ROOTDIR = os.environ.get(ROOTDIR_ENVVAR, os.path.expanduser('~/haggle'))
+
+
+def clog(condition, *args):
+    if condition:
+        print(*args)
+
+
+def handle_missing_dir(dirpath, prefix_msg='', ask_first=True, verbose=True):
+    if not os.path.isdir(dirpath):
+        if ask_first:
+            clog(verbose, prefix_msg)
+            clog(verbose, f"This directory doesn't exist: {dirpath}")
+            answer = input("Should I make that directory for you? ([Y]/n)?") or 'Y'
+            if next(iter(answer.strip().lower()), None) != 'y':
+                return
+        clog(verbose, f"Making {dirpath}...")
+        os.mkdir(dirpath)
+
 
 class DataInfoPaggedItems:
     def __init__(self):
@@ -182,7 +214,7 @@ from py2store.caching import mk_sourced_store
 from py2store.filesys import mk_relative_path_store, LocalFileDeleteMixin
 from py2store.stores.local_store import AutoMkDirsOnSetitemMixin, LocalJsonStore
 from py2store.trans import add_ipython_key_completions, kv_wrap
-from py2store.key_mappers.paths import str_template_key_trans
+from py2store.paths import str_template_key_trans
 from py2store.appendable import appendable
 
 
@@ -200,6 +232,7 @@ remote_key_trans = str_template_key_trans('{user}/{dataset_name}', str_template_
 @kv_wrap(local_zips_key_trans)
 class LocalKaggleZips(AutoMkDirsOnSetitemMixin, RelZipFiles):
     def __init__(self, rootdir):
+        handle_missing_dir(rootdir)
         super().__init__(rootdir=ensure_slash_suffix(rootdir), max_levels=1)
 
 
@@ -220,6 +253,7 @@ _KaggleDatasets = mk_sourced_store(
 @kv_wrap(local_meta_key_trans)
 class LocalKaggleMeta(AutoMkDirsOnSetitemMixin, LocalJsonStore):
     def __init__(self, rootdir):
+        handle_missing_dir(rootdir)
         super().__init__(path_format=ensure_slash_suffix(rootdir), max_levels=1)
 
 
@@ -236,8 +270,12 @@ KaggleMeta = mk_sourced_store(
 # TODO: Add caching of search results info locally
 @add_ipython_key_completions
 class KaggleDatasets(_KaggleDatasets):
-    def __init__(self, rootdir, cache_metas_on_search=True):
+    def __init__(self, rootdir=DFLT_ROOTDIR, cache_metas_on_search=True):
+        rootdir = rootdir or DFLT_ROOTDIR
+        handle_missing_dir(rootdir, "You (or defaults) asked for a rootdir...")
         self.rootdir = rootdir
+        handle_missing_dir(self.zips_dir, ask_first=False)
+        handle_missing_dir(self.meta_dir, ask_first=False)
         super().__init__(self.zips_dir)  # make the _KaggleDatasets instance
         self.meta = KaggleMeta(self.meta_dir)  # make the LocalKaggleInfo instance
         self.cache_metas_on_search = cache_metas_on_search
@@ -249,14 +287,14 @@ class KaggleDatasets(_KaggleDatasets):
     def zips_dir(self):
         return self.pjoin('zips')
 
-    @property
-    def kaggle_api(self):
-        return self._src.store._source  # TODO: Use dig methods instead (also perfect example of inconsistent naming!)
-
     @property
     def meta_dir(self):
         return self.pjoin('meta')
 
+    @property
+    def kaggle_api(self):
+        return self._src.store._source  # TODO: Use dig methods instead (also perfect example of inconsistent naming!)
+
     def search(self, search_term):
         ka = KaggleDatasetInfoReader(search=search_term)
         if self.cache_metas_on_search:
